#
# spec file for package pantheon-session
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pantheon-session
Version:        8.0.1
Release:        1.5
Summary:        The Pantheon Session Handler
License:        GPL-3.0-or-later
URL:            https://github.com/elementary/session-settings
Source0:        %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         remove-onboard.patch
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  gnome-keyring
BuildRequires:  meson
%if 0%{?suse_version} > 1600
BuildRequires:  onboard
%endif
BuildRequires:  orca
BuildRequires:  pkgconfig(gnome-settings-daemon)
BuildArch:      noarch

%description
Provides a session entry for display managers such as gdm or lightdm.

%prep
%autosetup -N -n session-settings-%{version}
%if 0%{?suse_version} <= 1600
%patch -P0 -p1
%endif

%build
%meson \
  -Dmimeapps-list=true \
  -Dfallback-session=icewom \
  -Ddetect-program-prefixes=false \
  -Dsystemd=true \
  -Dwayland=true
%meson_build

%install
%meson_install
%fdupes %{buildroot}

%if 0%{?suse_version} >= 1600
mkdir -p %{buildroot}%{_distconfdir}/xdg/autostart
mv %{buildroot}%{_sysconfdir}/xdg/autostart/*.desktop \
   %{buildroot}%{_distconfdir}/xdg/autostart/
%endif

%files
%license LICENSE
%doc README.md
%{_userunitdir}/gnome-session@{pantheon-wayland,pantheon}.target.d/session.conf
%{_datadir}/applications/pantheon-mimeapps.list
%{_datadir}/gnome-session/sessions/pantheon{,-wayland}.session
%{_datadir}/wayland-sessions/pantheon-wayland.desktop
%{_datadir}/xsessions/pantheon.desktop
%if 0%{?suse_version} >= 1600
%{_distconfdir}/xdg/autostart/*
%else
%{_sysconfdir}/xdg/autostart/*
%endif
%dir %{_datadir}/{gnome-session,gnome-session/sessions,wayland-sessions}
%dir %{_userunitdir}/gnome-session@pantheon{,-wayland}.target.d

%changelog
* Wed Nov  6 2024 Richard Rahl <rrahl0@opensuse.org>
- include remove-onboard.patch for Leap 16.0
- remove %%suse_update_desktop_file, as it's deprecated
* Tue Oct  1 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 8.0.1:
  * Correct PO dir
  * Rename X11 session to "Classic Session"
* Fri Aug 23 2024 Richard Rahl <rrahl0@opensuse.org>
- add remove-onboard.patch (for now only Leap)
* Wed Aug 21 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 8.0.0:
  * Add systemd support
  * systemd: also pull in GSD targets
  * Add optional Wayland session
  * Reflect new systemd target name
  * Remove gala-daemon
  * Require gnome-settings-daemon 3.36.0 and deduplicate gsd_components
  * Use systemd managed gnome-session
  * systemd: Install session.conf also to (wayland-session)
  * Rename sessions
- update to 6.0.0:
  * A fairly hefty rewrite that should make things more portable to other distros!
- switch url to github, as we don't want to link to a different OS
* Thu Aug 29 2019 Alexei Podvalsky <avvissu@yandex.by>
- Add .desktop file with gala settings
* Sun Dec 16 2018 Alexei Podvalsky <avvissu@yandex.by>
- Switch to pantheon-agent-polkit
* Sat Dec 15 2018 Alexei Podvalsky <avvissu@yandex.by>
- Remove pantheon-default-settings as required dependency when building
* Tue Nov 27 2018 Alexei Podvalsky <avvissu@yandex.by>
- Add pantheon-plank-dockitems.desktop.in
* Tue Oct 30 2018 Alexei Podvalsky <avvissu@yandex.by>
- Add gala-daemon to autostart
* Mon Oct  8 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 5.0.3:
  * New upstream release.
* Fri Aug 17 2018 avvissu@yandex.by
- Update to 5.0.2:
  * New upstream release.
* Thu Jun 14 2018 avvissu@yandex.by
- Add a new package with the default GSettings seetings
- Remove wayland package (no support)
- Install files using debian/install
* Mon Jun 11 2018 avvissu@yandex.by
- Update to 5.0.1:
  * Require cerbere >= 0.2.3
  * Add new cerbere symlink
  * Delete old cerbere symlink
  * Remove broken autostart for gnome-user-share
  * Remove broken Wayland session
  * Remove unity-greeter badge
  * Remove ScreensaverProxy GSD plugin because it breaks
    light-locker
  * Associate image/webp with Photo Viewer
  * Update defaults with new .desktop names
  * Partially revert 2d64ecb
  * Delete old GSD autostarts
  * Remove GSD components from session RequiredComponents
* Thu Mar 29 2018 avvissu@yandex.by
- Add SECTION test requirements
- Check that all the dependencies required by the package are present
- Update strings to GSD components
- Drop gnome-disk-utility
- Add  COPYING file
* Wed Mar 28 2018 avvissu@yandex.by
- Add XDG_MENU_PREFIX environment variable
* Fri Mar 23 2018 avvissu@yandex.by
- Add pantheon-default-settings as recommended dependency
* Sat Mar 17 2018 avvissu@yandex.by
- Spec file cleanup (drop openSUSE 42.x support)
* Mon Mar 12 2018 avvissu@yandex.by
- Add onboard as required dependency
- Spec file cleanup
* Sat Mar 10 2018 avvissu@yandex.by
- Add validation for required dependencies
* Sun Nov 12 2017 avvissu@yandex.by
- Update to 0.5+git20171008.8bd5b3:
  * Remove dropped GSD components from session
  * Update G-S-D components since split
- Remove GSD components from session on openSUSE_Leap
- Update GSD components on Factory
- Add onboard as recommended dependency
- Set default user session
- Add wayland package (Disable: session-wayland not recommended)
- Add orca as required dependency
- Switch from bzr to git
* Tue Nov  7 2017 avvissu@yandex.by
- Remove org.gnome.SettingsDaemon.ScreensaverProxy.desktop from
  xdg/autostart (screensaver-proxy plugin is blocking light-locker)
* Mon Nov  6 2017 avvissu@yandex.by
- Check list of dependencies when building RPM
- Use minimal version of the Gnome Session Manager (remove gdm
  defined as a dependency from libgdm ...):
  * add gnome-session-core as required dependency
* Wed Aug 30 2017 avvissu@yandex.by
- Add gsd-disk-utility-notify component
* Mon May  8 2017 avvissu@yandex.by
- Update to 0.5+bzr.82:
  * Restore new Maya desktop name
  * Temporarily revert new Maya desktop name
  * Defaults: associate image/gif with Photos
  * Update Photos desktop name
- Compatibility with gnome >= 3.22.4
* Sun Sep 18 2016 avvissu@yandex.by
- Update to 0.5+bzr.78
- Don't use mutter
- Change path to gnome-settings-daemon
- Spec file cleanup
* Sun Feb 28 2016 and.november@opensuse.org
- Nothing provides package slingshot
* Sat Feb 27 2016 mailaender@opensuse.org
- Update to bzr revision 65
  * Add wayland desktop and gnome-session files
  * Drop gconf
- Set fallback to GNOME 3 instead of Ubuntu Unity
* Tue May 19 2015 mailaender@opensuse.org
- initial package (version bzr.63) for build.opensuse.org
